@@ -28,82 +28,67 @@ github_document <- function(toc = FALSE,
                             html_preview = TRUE) {
 
   # add special markdown rendering template to ensure we include the title fields
-  pandoc_args <- c(pandoc_args, "--template",
-                   pandoc_path_arg(rmarkdown_system_file(
-                    "rmarkdown/templates/github_document/resources/default.md")))
+  pandoc_args <- c(
+    pandoc_args, "--template", pandoc_path_arg(rmarkdown_system_file(
+      "rmarkdown/templates/github_document/resources/default.md"))
+  )
 
+  pandoc2 <- pandoc2.0()
   # use md_document as base
-  variant <- if (pandoc_available("2.0")) "gfm" else "markdown_github"
-  if (!hard_line_breaks)
-    variant <- paste0(variant, "-hard_line_breaks")
+  variant <- if (pandoc2) "gfm" else "markdown_github"
+  if (!hard_line_breaks) variant <- paste0(variant, "-hard_line_breaks")
 
   # turn off ASCII identifiers
   variant <- paste0(variant, "-ascii_identifiers")
 
-  format <- md_document(variant = variant,
-                        toc = toc,
-                        toc_depth = toc_depth,
-                        fig_width = fig_width,
-                        fig_height = fig_height,
-                        dev = dev,
-                        df_print = df_print,
-                        includes = includes,
-                        md_extensions = md_extensions,
-                        pandoc_args = pandoc_args)
+  format <- md_document(
+    variant = variant, toc = toc, toc_depth = toc_depth,
+    fig_width = fig_width, fig_height = fig_height, dev = dev,
+    df_print = df_print, includes = includes, md_extensions = md_extensions,
+    pandoc_args = pandoc_args
+  )
 
   # remove 'ascii_identifiers' if necessary -- required to ensure that
   # TOC links are correctly generated on GitHub
-  format$pandoc$from <-
-    gsub("+ascii_identifiers", "", format$pandoc$from, fixed = TRUE)
+  format$pandoc$from <- gsub("+ascii_identifiers", "", format$pandoc$from, fixed = TRUE)
 
   # add a post processor for generating a preview if requested
   if (html_preview) {
     format$post_processor <- function(metadata, input_file, output_file, clean, verbose) {
 
-      # build pandoc args
-      args <- c()
-
-      # provide a preview that looks like github
-      args <- c(args, "--standalone")
-      args <- c(args, "--self-contained")
-      args <- c(args, "--highlight-style", "pygments")
-      args <- c(args, "--template",
-                pandoc_path_arg(rmarkdown_system_file(
-                  "rmarkdown/templates/github_document/resources/preview.html")))
       css <- pandoc_path_arg(rmarkdown_system_file(
         "rmarkdown/templates/github_document/resources/github.css"))
-      args <- c(args, "--variable", paste("github-markdown-css:", css, sep=""))
-
-      # no email obfuscation
-      args <- c(args, "--email-obfuscation", "none")
+      # provide a preview that looks like github
+      args <- c(
+        "--standalone", "--self-contained", "--highlight-style", "pygments",
+        "--template", pandoc_path_arg(rmarkdown_system_file(
+          "rmarkdown/templates/github_document/resources/preview.html")),
+        "--variable", paste0("github-markdown-css:", css),
+        "--email-obfuscation", "none", # no email obfuscation
+        if (pandoc2) c("--metadata", "pagetitle=PREVIEW")  # HTML5 requirement
+      )
 
       # run pandoc
       preview_file <- file_with_ext(output_file, "html")
-      pandoc_convert(input = output_file,
-                     to = "html",
-                     from = variant,
-                     output = preview_file,
-                     options = args,
-                     verbose = verbose)
+      pandoc_convert(
+        input = output_file, to = "html", from = variant, output = preview_file,
+        options = args, verbose = verbose
+      )
 
       # move the preview to the preview_dir if specified
       preview_dir <- Sys.getenv("RMARKDOWN_PREVIEW_DIR", unset = NA)
       if (!is.na(preview_dir)) {
-        relocated_preview_file <- tempfile(pattern = "preview-",
-                                           tmpdir = preview_dir,
-                                           fileext = ".html")
+        relocated_preview_file <- tempfile("preview-", preview_dir, ".html")
         file.copy(preview_file, relocated_preview_file)
         file.remove(preview_file)
         preview_file <- relocated_preview_file
       }
 
-      if (verbose)
-        message("\nPreview created: ", preview_file)
+      if (verbose) message("\nPreview created: ", preview_file)
 
       output_file
     }
   }
 
-  # return format
-  format
+  format  # return format
 }
