@@ -359,7 +359,7 @@ discover_rmd_resources <- function(rmd_file, encoding,
   output_format <- output_format_from_yaml_front_matter(rmd_content,
                                                         encoding = encoding)
   output_format_function <- eval(parse(text = output_format$name))
-  override_output_format <- if (output_format_function()$pandoc$to == "html")
+  override_output_format <- if (is_pandoc_to_html(output_format_function()$pandoc))
                               NULL
                             else
                               "html_document"
@@ -379,7 +379,12 @@ discover_rmd_resources <- function(rmd_file, encoding,
   # if this is an R Markdown file, purl the file to extract just the R code
   if (tolower(tools::file_ext(rmd_file)) == "rmd") {
     r_file <- tempfile(fileext = ".R")
-    on.exit(unlink(r_file), add = TRUE)
+    # suppress possible try() errors https://github.com/rstudio/rmarkdown/issues/1247
+    try_file <- tempfile()
+    opts <- options(try.outFile = try_file)
+    on.exit({
+      unlink(c(r_file, try_file)); options(opts)
+    }, add = TRUE)
     knitr::purl(md_file, output = r_file, quiet = TRUE, documentation = 0,
                 encoding = "UTF-8")
     temp_files <- c(temp_files, r_file)
